@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #define SIGSEGV_EXC_STATE_TYPE                      ppc_exception_state_t
 #define SIGSEGV_EXC_STATE_FLAVOR                    PPC_EXCEPTION_STATE
